@@ -23,26 +23,28 @@
 #include "client/Response.hxx"
 #include "util/StringView.hxx"
 
+#include <fmt/format.h>
+
 void
 tag_print_types(Response &r) noexcept
 {
 	const auto tag_mask = global_tag_mask & r.GetTagMask();
 	for (unsigned i = 0; i < TAG_NUM_OF_ITEM_TYPES; i++)
 		if (tag_mask.Test(TagType(i)))
-			r.Format("tagtype: %s\n", tag_item_names[i]);
+			r.Fmt(FMT_STRING("tagtype: {}\n"), tag_item_names[i]);
 }
 
 void
-tag_print(Response &r, TagType type, StringView value) noexcept
+tag_print(Response &r, TagType type, StringView _value) noexcept
 {
-	r.Format("%s: %.*s\n", tag_item_names[type],
-		 int(value.size), value.data);
+	const std::string_view value{_value};
+	r.Fmt(FMT_STRING("{}: {}\n"), tag_item_names[type], value);
 }
 
 void
 tag_print(Response &r, TagType type, const char *value) noexcept
 {
-	r.Format("%s: %s\n", tag_item_names[type], value);
+	r.Fmt(FMT_STRING("{}: {}\n"), tag_item_names[type], value);
 }
 
 void
@@ -58,10 +60,10 @@ void
 tag_print(Response &r, const Tag &tag) noexcept
 {
 	if (!tag.duration.IsNegative())
-		r.Format("Time: %i\n"
-			 "duration: %1.3f\n",
-			 tag.duration.RoundS(),
-			 tag.duration.ToDoubleS());
+		r.Fmt(FMT_STRING("Time: {}\n"
+				 "duration: {:1.3f}\n"),
+		      tag.duration.RoundS(),
+		      tag.duration.ToDoubleS());
 
 	tag_print_values(r, tag);
 }
