@@ -36,10 +36,10 @@
 gcc_pure
 static bool
 CheckDecoderPlugin(const DecoderPlugin &plugin,
-		   const char *suffix, const char *mime) noexcept
+		   std::string_view suffix, std::string_view mime) noexcept
 {
-	return (mime != nullptr && plugin.SupportsMimeType(mime)) ||
-		(suffix != nullptr && plugin.SupportsSuffix(suffix));
+	return (!mime.empty() && plugin.SupportsMimeType(mime)) ||
+		(!suffix.empty() && plugin.SupportsSuffix(suffix));
 }
 
 bool
@@ -47,25 +47,24 @@ tag_stream_scan(InputStream &is, TagHandler &handler)
 {
 	assert(is.IsReady());
 
-	UriSuffixBuffer suffix_buffer;
-	const char *const suffix = uri_get_suffix(is.GetURI(), suffix_buffer);
-	const char *mime = is.GetMimeType();
+	const auto suffix = uri_get_suffix(is.GetURI());
+	const char *full_mime = is.GetMimeType();
 
-	if (suffix == nullptr && mime == nullptr)
+	if (suffix.empty() && full_mime == nullptr)
 		return false;
 
-	std::string mime_base;
-	if (mime != nullptr)
-		mime = (mime_base = GetMimeTypeBase(mime)).c_str();
+	std::string_view mime_base{};
+	if (full_mime != nullptr)
+		mime_base = GetMimeTypeBase(full_mime);
 
-	return decoder_plugins_try([suffix, mime, &is,
+	return decoder_plugins_try([suffix, mime_base, &is,
 				    &handler](const DecoderPlugin &plugin){
 			try {
 				is.LockRewind();
 			} catch (...) {
 			}
 
-			return CheckDecoderPlugin(plugin, suffix, mime) &&
+			return CheckDecoderPlugin(plugin, suffix, mime_base) &&
 				plugin.ScanStream(is, handler);
 		});
 }
