@@ -44,7 +44,7 @@ Client::OnTimeout() noexcept
 		assert(!idle_waiting);
 		assert(!background_command);
 
-		FormatDebug(client_domain, "[%u] timeout", num);
+		FmtDebug(client_domain, "[{}] timeout", num);
 	}
 
 	Close();
