@@ -23,7 +23,7 @@
 #include "filter/Prepared.hxx"
 #include "pcm/Buffer.hxx"
 #include "pcm/AudioFormat.hxx"
-#include "AudioCompress/compress.h"
+#include "pcm/AudioCompress/compress.h"
 #include "util/ConstBuffer.hxx"
 
 #include <string.h>
