@@ -523,7 +523,13 @@ PipeWireOutput::Open(AudioFormat &audio_format)
 		pw_properties_setf(props, PW_KEY_REMOTE_NAME, "%s", remote);
 
 	if (target != nullptr && target_id == PW_ID_ANY)
-		pw_properties_setf(props, PW_KEY_NODE_TARGET, "%s", target);
+		pw_properties_setf(props,
+#if PW_CHECK_VERSION(0, 3, 64)
+				   PW_KEY_TARGET_OBJECT,
+#else
+				   PW_KEY_NODE_TARGET,
+#endif
+				   "%s", target);
 
 #ifdef PW_KEY_NODE_RATE
 	/* ask PipeWire to change the graph sample rate to ours
@@ -967,6 +973,8 @@ PipeWireOutput::SendTag(const Tag &tag)
 
 	struct spa_dict dict = SPA_DICT_INIT(items, n_items);
 
+	const PipeWire::ThreadLoopLock lock(thread_loop);
+
 	auto rc = pw_stream_update_properties(stream, &dict);
 	if (rc < 0)
 		LogWarning(pipewire_output_domain, "Error updating properties");
